Package

Type Alias Package 

pub type Package<M> = Package<BluePallas<M>>;
The package that must be broadcast by each participant to all other participants between the first and second parts of the DKG protocol (round 1).

Aliased Type

pub struct Package<M> { /* private fields */ }