pub type SecretPackage<M> = SecretPackage<BluePallas<M>>;Expand description
The secret package that must be kept in memory by the participant between the first and second parts of the DKG protocol (round 1).
Security
This package MUST NOT be sent to other participants!
Aliased Type
pub struct SecretPackage<M> { /* private fields */ }